====
Dots
====

PyGame app to interact with the `Dots board`_ for the `Raspberry Pi`_ used as a *connect the dots* puzzle.

Installation
============

On Raspberry Pi, install the *rpi_dots* module in pip.

Python 3::

    sudo apt-get install python3-pip
    sudo pip-3.2 install rpi_dots

Python 2::

    sudo apt-get install python-pip
    sudo pip install rpi_dots

Usage
=====

Run from the command line::

    sudo rpi_dots

Contributors
============

* `Eben Upton`_
* `Ben Nuttall`_

Open Source
===========

* The code is licensed under the `BSD Licence`_
* The project source code is hosted on `GitHub`_
* Please use `GitHub issues`_ to submit bugs and report issues


.. _Dots board: http://www.raspberrypi.org/dots/
.. _Raspberry Pi: http://www.raspberrypi.org/
.. _Eben Upton: https://github.com/ebenupton
.. _Ben Nuttall: https://github.com/bennuttall
.. _BSD Licence: http://opensource.org/licenses/BSD-3-Clause
.. _GitHub: https://github.com/raspberrypilearning/dots
.. _GitHub Issues: https://github.com/raspberrypilearning/dots/issues
